Package: eddington
Title: Compute a Cyclist's Eddington Number
Version: 4.3.0
Authors@R: c(
    person('Paul', 'Egeler', email = 'paulegeler@gmail.com', role = c('aut','cre')),
    person('Tashi', 'Reigle', role = 'ctb'))
Description: Compute a cyclist's Eddington number, including efficiently
    computing cumulative E over a vector. A cyclist's Eddington number
    <https://en.wikipedia.org/wiki/Arthur_Eddington#Eddington_number_for_cycling>
    is the maximum number satisfying the condition such that a cyclist has
    ridden E miles or greater on E distinct days. The algorithm in this package
    is an improvement over the conventional approach because both summary
    statistics and cumulative statistics can be computed in linear time, since
    it does not require initial sorting of the data. These functions may also be
    used for computing h-indices for authors, a metric described by Hirsch (2005)
    <doi:10.1073/pnas.0507655102>. Both are specific applications of computing
    the side length of a Durfee square <https://en.wikipedia.org/wiki/Durfee_square>.
    Some additional author-level metrics such as g-index and i10-index are also
    included in the package.
License: GPL (>= 2)
Encoding: UTF-8
LazyData: true
Depends: R (>= 4.2.0)
LinkingTo: Rcpp
Imports: Rcpp, R6, methods, xml2
Suggests: testthat, knitr, rmarkdown, stats, dplyr, tibble
SystemRequirements: C++17
VignetteBuilder: knitr
RoxygenNote: 7.3.2
URL: https://github.com/pegeler/eddington2
BugReports: https://github.com/pegeler/eddington2/issues
NeedsCompilation: yes
Packaged: 2026-04-12 03:16:10 UTC; pablo
Author: Paul Egeler [aut, cre],
  Tashi Reigle [ctb]
Maintainer: Paul Egeler <paulegeler@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-13 21:00:02 UTC
Built: R 4.5.2; x86_64-apple-darwin20; 2026-04-13 23:27:06 UTC; unix
Archs: eddington.so.dSYM
