# Generated by roxygen2: do not edit by hand

S3method(print,E_next)
export(E_cum)
export(E_next)
export(E_num)
export(E_req)
export(E_sat)
export(Eddington)
export(EddingtonModule)
export(durfee)
export(g_index)
export(get_haversine_distance)
export(h_index)
export(i10_index)
export(index)
export(read_gpx)
importFrom(R6,R6Class)
importFrom(Rcpp,loadModule)
importFrom(Rcpp,sourceCpp)
importFrom(methods,new)
useDynLib(eddington, .registration = TRUE)
