% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rides.r
\docType{data}
\name{rides}
\alias{rides}
\title{A year of simulated bicycle ride mileages}
\format{
A data frame with 250 rows and 2 variables:
\describe{
\item{ride_date}{date the ride occurred}
\item{ride_length}{the length in miles}
}
}
\usage{
rides
}
\description{
Simulated dates and distances of rides occurring in 2009.
}
\details{
The dataset contains a total of 3,419 miles spread across 178
unique days. The Eddington number for the year was 29.
}
\seealso{
\link{daily_totals}
}
\keyword{datasets}
